@@ -90,11 +90,7 @@ class BadgeRule(object):
 
         self.tahrir = tahrir_database
         if self.tahrir:
-            # If the badge already exists in the tahrir DB, this just returns
-            # False.  We don't care.  We just want it to exist from this point
-            # on.
-            self.badge_id = self._d['name'].lower().replace(" ", "-")
-            self.tahrir.add_badge(
+            self.badge_id = self.tahrir.add_badge(
                 name=self._d['name'],
                 image=self._d['image_url'],
                 desc=self._d['description'],
